INSERT IGNORE INTO `engine4_storage_servicetypes` (`title`, `plugin`, `form`, `enabled`) VALUES 
('Wasabi Cloud Storage', 'Storage_Service_Wasabi', 'Storage_Form_Admin_Service_Wasabi', '1'),
('Digital Ocean Space', 'Storage_Service_Digitalocean', 'Storage_Form_Admin_Service_Digitalocean', 1),
('Amazon S3 Compatible Storage', 'Storage_Service_AmazonS3', 'Storage_Form_Admin_Service_AmazonS3', 1);
