<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Storage_Form_Admin_Service_Local extends Storage_Form_Admin_Service_Generic
{
  public function init()
  {
    // Element: path
    $this->addElement('Text', 'path', array(
      'label' => 'Path Prefix',
      'description' => 'This is prepended to the file path on upload. Defaults ' 
          . 'to "public". Must be relative to the SocialEngine path.',
    ));
    
    // Element: baseUrl
    $this->addElement('Text', 'baseUrl', array(
      'label' => 'Base URL',
      'description' => 'This is the base URL used for generating the file ' . 
          'URLs. Should only be used for pull-type CDNs.',
      'filters' => array(
        'StringTrim',
      ),
    ));
    
    parent::init();
  }
}
